==> nextcloud-28.0.5.tar.bz2: nextcloud/apps/photos/l10n/en_GB.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Public link",
    "Photos" : "Photos",
    "On This Day" : "On This Day",
    "Your memories under your control" : "Your memories under your control",
    "All media" : "All media",
    "Videos" : "Videos",
    "Albums" : "Albums",
    "Collaborative albums" : "Collaborative albums",
    "People" : "People",
    "Folders" : "Folders",
    "Favorites" : "Favourites",
    "On this day" : "On this day",
    "Shared with you" : "Shared with you",
    "Tags" : "Tags",
    "Places" : "Places",
    "Map" : "Map",
    "Photos settings" : "Photos settings",
    "Mark selection as favorite" : "Mark selection as favourite",
    "Add selection to favorites" : "Add selection to favourites",
    "Remove selection from favorites" : "Remove selection from favourites",
    "Name of the album" : "Name of the album",
    "Location of the album" : "Location of the album",
    "Back" : "Back",
    "Add collaborators" : "Add collaborators",
    "Save" : "Save",
    "Create album" : "Create album",
    "Add to Album" : "Add to Album",
    "Add selection to album {albumName}" : "Add selection to album {albumName}",
    "Shared by" : "Shared by",
    "Create a new album." : "Create a new album.",
    "Create new album" : "Create new album",
    "New album" : "New album",
    "_%n item_::_%n photos and videos_" : ["%n item","%n photos and videos"],
    "Add people or groups who can edit your album" : "Add people or groups who can edit your album",
    "Search people or groups" : "Search people or groups",
    "No recommendations. Start typing." : "No recommendations. Start typing.",
    "Group" : "Group",
    "Remove {collaboratorLabel} from the collaborators list" : "Remove {collaboratorLabel} from the collaborators list",
    "Copy the public link" : "Copy the public link",
    "Public link copied!" : "Public link copied!",
    "Copy public link" : "Copy public link",
    "Delete the public link" : "Delete the public link",
    "Create public link share" : "Create public link share",
    "Share via public link" : "Share via public link",
    "Failed to fetch collaborators list." : "Failed to fetch collaborators list.",
    "Failed to update album." : "Failed to update album.",
    "This collection does not exist" : "This collection does not exist",
    "An error occurred" : "An error occurred",
    "No picture for this day" : "No picture for this day",
    "Picture taken on this day will show up here." : "Picture taken on this day will show up here.",
    "More photos from this day" : "More photos from this day",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n unassigned photo","%n unassigned photos"],
    "Favorite" : "Favourite",
    "Select image {imageName}" : "Select image {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Favourite image, open the full size \"{name}\" image",
    "Open the full size \"{name}\" image" : "Open the full size \"{name}\" image",
    "Open the \"{name}\" folder" : "Open the \"{name}\" folder",
    "Go back" : "Go back",
    "Back to {folder}" : "Back to {folder}",
    "Share this folder" : "Share this folder",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Jump to specific date in list",
    "Jump to {date}" : "Jump to {date}",
    "Add to {destination}" : "Add to {destination}",
    "There are no photos or videos yet!" : "There are no photos or videos yet!",
    "_{years} year ago_::_{years} years ago_" : ["{years} year ago","{years} years ago"],
    "Enable squared photos view" : "Enable squared photos view",
    "Delete source directory" : "Delete source directory",
    "All folders" : "All folders",
    "Add a Photos source for the timelines" : "Add a Photos source for the timelines",
    "Add folder" : "Add folder",
    "Select a source folder for your media" : "Select a source folder for your media",
    "Home" : "Home",
    "Choose default Photos upload and Albums location" : "Choose default Photos upload and Albums location",
    "Choose a different folder" : "Choose a different folder",
    "Select the default upload location for your media" : "Select the default upload location for your media",
    "View" : "View",
    "Media folders" : "Media folders",
    "Choose the folders from where photos and videos are shown." : "Choose the folders from where photos and videos are shown.",
    "Upload folder" : "Upload folder",
    "Choose the folder where photos and albums are uploaded to." : "Choose the folder where photos and albums are uploaded to.",
    "_%n photo_::_%n photos_" : ["%n photo","%n photos"],
    "Unselect all" : "Unselect all",
    "Manage collaborators for this album" : "Manage collaborators for this album",
    "Open actions menu" : "Open actions menu",
    "Edit album details" : "Edit album details",
    "Download all files in album" : "Download all files in album",
    "Delete album" : "Delete album",
    "Download selected files" : "Download selected files",
    "Remove selection from album" : "Remove selection from album",
    "This album does not have any photos or videos yet!" : "This album does not have any photos or videos yet!",
    "Add photos to this album" : "Add photos to this album",
    "Add photos to {albumName}" : "Add photos to {albumName}",
    "Manage collaborators" : "Manage collaborators",
    "Save collaborators for this album." : "Save collaborators for this album.",
    "Cover photo for album {albumName}" : "Cover photo for album {albumName}",
    "There is no album yet!" : "There is no album yet!",
    "This person could not be found" : "This person could not be found",
    "Rename person" : "Rename person",
    "Merge with different person" : "Merge with different person",
    "Download selected photos" : "Download selected photos",
    "Remove from favorites" : "Remove from favourites",
    "Remove person" : "Remove person",
    "Name of this person" : "Name of this person",
    "Save." : "Save.",
    "Merge person" : "Merge person",
    "Move to different person" : "Move to different person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Move photo to a different person","Move photos to a different person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remove photo from person","Remove photos from person"],
    "This might take some time depending on the size of your photo library." : "This might take some time depending on the size of your photo library.",
    "Recognized people will show up here" : "Recognised people will show up here",
    "This folder does not exist" : "This folder does not exist",
    "Loading folders …" : "Loading folders …",
    "No photos in here" : "No photos in here",
    "Taken on {date} at {time}" : "Taken on {date} at {time}",
    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
    "Add photos to this place" : "Add photos to this place",
    "Cover photo for place {placeName}" : "Cover photo for place {placeName}",
    "There is no place yet!" : "There is no place yet!",
    "Cover photo for shared album {albumName}." : "Cover photo for shared album {albumName}.",
    "Back to tags overview" : "Back to tags overview",
    "No photos with this tag yet" : "No photos with this tag yet",
    "No tags yet" : "No tags yet",
    "Photos with tags will show up here" : "Photos with tags will show up here",
    "Popular tags" : "Popular tags",
    "One of the source folders does not exists" : "One of the source folders does not exists",
    "Add" : "Add",
    "Add to album" : "Add to album",
    "Delete selection" : "Delete selection",
    "No photos or videos in here" : "No photos or videos in here",
    "Unassigned faces" : "Unassigned faces",
    "_%n photos_::_%n photos_" : ["%n photos","%n photos"],
    "Failed to fetch collection." : "Failed to fetch collection.",
    "Failed to fetch collections list." : "Failed to fetch collections list.",
    "Failed to fetch faces list." : "Failed to fetch faces list.",
    "All your media" : "All your media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Shared Albums",
    "Shared album {title}" : "Shared album {title}",
    "Public album {title}" : "Public album {title}",
    "Tagged photos" : "Tagged photos",
    "Tagged photo {title}" : "Tagged photo {title}",
    "{title}'s face" : "{title}'s face",
    "{startDate} to {endDate}" : "{startDate} to {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}." : "Failed to rename {oldName} to {faceName}.",
    "Failed to delete {faceName}." : "Failed to delete {faceName}.",
    "Failed to delete {fileId}." : "Failed to delete {fileId}.",
    "Failed to delete {fileName}." : "Failed to delete {fileName}.",
    "Failed to set favorite state for {fileId}." : "Failed to set favourite state for {fileId}.",
    "Failed to set favorite state for {fileName}." : "Failed to set favourite state for {fileName}.",
    "Could not load photos folder" : "Could not load photos folder",
    "Go back to the previous view." : "Go back to the previous view.",
    "Go to the add collaborators view." : "Go to the add collaborators view.",
    "Create the album." : "Create the album.",
    "Back to the new album form." : "Back to the new album form.",
    "_Share with %n user_::_Share with %n users_" : ["Share with %n user","Share with %n users"],
    "Search for collaborators" : "Search for collaborators",
    "Add {collaboratorLabel} to the collaborators list" : "Add {collaboratorLabel} to the collaborators list",
    "No collaborators available" : "No collaborators available",
    "Failed to fetch album." : "Failed to fetch album.",
    "The file is in the favorites" : "The file is in the favourites",
    "Open the \"{name}\" sub-directory" : "Open the \"{name}\" sub-directory",
    "Default Photos upload and Albums location" : "Default Photos upload and Albums location",
    "Select the default location for your media" : "Select the default location for your media",
    "Invalid location selected" : "Invalid location selected",
    "Photos directory" : "Photos directory",
    "Add photos to the album" : "Add photos to the album",
    "Failed to fetch albums list." : "Failed to fetch albums list.",
    "Shared albums" : "Shared albums",
    "Create a new album" : "Create a new album",
    "Add selection to an album" : "Add selection to an album",
    "Failed to create {albumName}." : "Failed to create {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Failed to rename {currentAlbumName} to {newAlbumName}.",
    "Choose a Photos source for the timelines" : "Choose a Photos source for the timelines",
    "Media folder" : "Media folder",
    "The source folder does not exists" : "The source folder does not exists"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/photos/l10n/en_GB.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Public link",
    "Photos" : "Photos",
    "On This Day" : "On This Day",
    "Your memories under your control" : "Your memories under your control",
    "All media" : "All media",
    "Videos" : "Videos",
    "Albums" : "Albums",
    "Collaborative albums" : "Collaborative albums",
    "People" : "People",
    "Folders" : "Folders",
    "Favorites" : "Favourites",
    "On this day" : "On this day",
    "Shared with you" : "Shared with you",
    "Tags" : "Tags",
    "Places" : "Places",
    "Map" : "Map",
    "Photos settings" : "Photos settings",
    "Mark selection as favorite" : "Mark selection as favourite",
    "Add selection to favorites" : "Add selection to favourites",
    "Remove selection from favorites" : "Remove selection from favourites",
    "Name of the album" : "Name of the album",
    "Location of the album" : "Location of the album",
    "Back" : "Back",
    "Add collaborators" : "Add collaborators",
    "Save" : "Save",
    "Create album" : "Create album",
    "Add to Album" : "Add to Album",
    "Add selection to album {albumName}" : "Add selection to album {albumName}",
    "Shared by" : "Shared by",
    "Create a new album." : "Create a new album.",
    "Create new album" : "Create new album",
    "New album" : "New album",
    "_%n item_::_%n photos and videos_" : ["%n item","%n photos and videos"],
    "Failed to fetch collaborators list." : "Failed to fetch collaborators list.",
    "Failed to update album." : "Failed to update album.",
    "Add people or groups who can edit your album" : "Add people or groups who can edit your album",
    "Search people or groups" : "Search people or groups",
    "No recommendations. Start typing." : "No recommendations. Start typing.",
    "Group" : "Group",
    "Remove {collaboratorLabel} from the collaborators list" : "Remove {collaboratorLabel} from the collaborators list",
    "Copy the public link" : "Copy the public link",
    "Public link copied!" : "Public link copied!",
    "Copy public link" : "Copy public link",
    "Delete the public link" : "Delete the public link",
    "Create public link share" : "Create public link share",
    "Share via public link" : "Share via public link",
    "This collection does not exist" : "This collection does not exist",
    "An error occurred" : "An error occurred",
    "No picture for this day" : "No picture for this day",
    "Picture taken on this day will show up here." : "Picture taken on this day will show up here.",
    "More photos from this day" : "More photos from this day",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n unassigned photo","%n unassigned photos"],
    "Favorite" : "Favourite",
    "Favorite image, open the full size \"{name}\" image" : "Favourite image, open the full size \"{name}\" image",
    "Open the full size \"{name}\" image" : "Open the full size \"{name}\" image",
    "Select image {imageName}" : "Select image {imageName}",
    "Open the \"{name}\" folder" : "Open the \"{name}\" folder",
    "Back to {folder}" : "Back to {folder}",
    "Go back" : "Go back",
    "Share this folder" : "Share this folder",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Jump to specific date in list",
    "Jump to {date}" : "Jump to {date}",
    "Add to {destination}" : "Add to {destination}",
    "The destination folder is owned by {owner}" : "The destination folder is owned by {owner}",
    "There are no photos or videos yet!" : "There are no photos or videos yet!",
    "_{years} year ago_::_{years} years ago_" : ["{years} year ago","{years} years ago"],
    "Enable squared photos view" : "Enable squared photos view",
    "Delete source directory" : "Delete source directory",
    "Pick folder" : "Pick folder",
    "Select a source folder for your media" : "Select a source folder for your media",
    "All folders" : "All folders",
    "Add a Photos source for the timelines" : "Add a Photos source for the timelines",
    "Add folder" : "Add folder",
    "Select the default upload location for your media" : "Select the default upload location for your media",
    "Home" : "Home",
    "Choose default Photos upload and Albums location" : "Choose default Photos upload and Albums location",
    "Choose a different folder" : "Choose a different folder",
    "View" : "View",
    "Media folders" : "Media folders",
    "Choose the folders from where photos and videos are shown." : "Choose the folders from where photos and videos are shown.",
    "Upload folder" : "Upload folder",
    "Choose the folder where photos and albums are uploaded to." : "Choose the folder where photos and albums are uploaded to.",
    "_%n photo_::_%n photos_" : ["%n photo","%n photos"],
    "Unselect all" : "Unselect all",
    "Add photos to this album" : "Add photos to this album",
    "Manage collaborators for this album" : "Manage collaborators for this album",
    "Open actions menu" : "Open actions menu",
    "Edit album details" : "Edit album details",
    "Download all files in album" : "Download all files in album",
    "Delete album" : "Delete album",
    "Download selected files" : "Download selected files",
    "Remove selection from album" : "Remove selection from album",
    "This album does not have any photos or videos yet!" : "This album does not have any photos or videos yet!",
    "Add photos to {albumName}" : "Add photos to {albumName}",
    "Manage collaborators" : "Manage collaborators",
    "Save collaborators for this album." : "Save collaborators for this album.",
    "Cover photo for album {albumName}" : "Cover photo for album {albumName}",
    "There is no album yet!" : "There is no album yet!",
    "This person could not be found" : "This person could not be found",
    "Rename person" : "Rename person",
    "Merge with different person" : "Merge with different person",
    "Download selected photos" : "Download selected photos",
    "Remove from favorites" : "Remove from favourites",
    "Remove person" : "Remove person",
    "Name of this person" : "Name of this person",
    "Save." : "Save.",
    "Merge person" : "Merge person",
    "Move to different person" : "Move to different person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Move photo to a different person","Move photos to a different person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remove photo from person","Remove photos from person"],
    "This might take some time depending on the size of your photo library." : "This might take some time depending on the size of your photo library.",
    "Recognized people will show up here" : "Recognised people will show up here",
    "This folder does not exist" : "This folder does not exist",
    "Loading folders …" : "Loading folders …",
    "No photos in here" : "No photos in here",
    "Taken on {date} at {time}" : "Taken on {date} at {time}",
    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
    "Add photos to this place" : "Add photos to this place",
    "Cover photo for place {placeName}" : "Cover photo for place {placeName}",
    "There is no place yet!" : "There is no place yet!",
    "Cover photo for shared album {albumName}." : "Cover photo for shared album {albumName}.",
    "Back to tags overview" : "Back to tags overview",
    "No photos with this tag yet" : "No photos with this tag yet",
    "No tags yet" : "No tags yet",
    "Photos with tags will show up here" : "Photos with tags will show up here",
    "Popular tags" : "Popular tags",
    "All tags" : "All tags",
    "One of the source folders does not exist" : "One of the source folders does not exist",
    "Add to album" : "Add to album",
    "Delete selection" : "Delete selection",
    "No photos or videos in here" : "No photos or videos in here",
    "Unassigned faces" : "Unassigned faces",
    "_%n photos_::_%n photos_" : ["%n photos","%n photos"],
    "Failed to fetch collection." : "Failed to fetch collection.",
    "Failed to fetch collections list." : "Failed to fetch collections list.",
    "Failed to fetch faces list." : "Failed to fetch faces list.",
    "All your media" : "All your media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Shared Albums",
    "Shared album {title}" : "Shared album {title}",
    "Public album {title}" : "Public album {title}",
    "Tagged photos" : "Tagged photos",
    "Tagged photo {title}" : "Tagged photo {title}",
    "{title}'s face" : "{title}'s face",
    "{startDate} to {endDate}" : "{startDate} to {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}." : "Failed to rename {oldName} to {faceName}.",
    "Failed to delete {faceName}." : "Failed to delete {faceName}.",
    "Failed to delete {fileId}." : "Failed to delete {fileId}.",
    "Failed to delete {fileName}." : "Failed to delete {fileName}.",
    "Failed to set favorite state for {fileId}." : "Failed to set favourite state for {fileId}.",
    "Failed to set favorite state for {fileName}." : "Failed to set favourite state for {fileName}.",
    "Could not load photos folder" : "Could not load photos folder",
    "One of the source folders does not exists" : "One of the source folders does not exists",
    "Add" : "Add"
},
"nplurals=2; plural=(n != 1);");
